#
# spec file for package python-datrie
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-datrie
Version:        0.8.2
Release:        5.3
Summary:        Trie data structure for Python
License:        LGPL-2.1-or-later
URL:            https://github.com/kmike/datrie
Source:         https://files.pythonhosted.org/packages/source/d/datrie/datrie-%{version}.tar.gz
Patch0:         datrie-bigendian.patch
# PATCH-FIX-UPSTREAM - Fix AlphaMap definition in cdatrie.pxd
Patch1:         https://github.com/pytries/datrie/pull/99.patch
BuildRequires:  %{python_module Cython >= 0.26.1}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
A trie data structure for Python (2.x and 3.x). Uses libdatrie.

%prep
%autosetup -p1 -n datrie-%{version}
# https://github.com/pytries/datrie/pull/89
sed -i 's:pytest-runner::' setup.py

%build
pushd src
cython datrie.pyx
cython *.pxd
popd
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license COPYING
%doc README.rst CHANGES.rst
%{python_sitearch}/datrie.cpython-*linux*.so
%{python_sitearch}/datrie-%{version}.dist-info

%changelog
* Tue May 28 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with GCC 14
  * https://github.com/pytries/datrie/pull/99.patch
* Thu Feb 29 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Thu Dec  9 2021 pgajdos@suse.com
- do not require pytest-runner for build, not required
* Mon May 17 2021 pgajdos@suse.com
- use %%pytest_arch macro
* Thu Apr  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.2
  * Future-proof Python support by making cython a build time dependency and
    removing cython generated c files from the repo (and sdist).
  * Fix collections.abc.MutableMapping import
  * CI and test updates
  * Adjust library name to unbreak some linkers
* Thu Jul 25 2019 pgajdos@suse.com
- version update to 0.8
  * Python 3.7 compatibility; extension is rebuilt with Cython 0.29.11.
  * Trie.get function;
  * Python 2.6 and 3.3 support is dropped;
  * removed patch to libdatrie which is no longer required;
  * testing and CI fixes.
- deleted patches
  - merged_pr_60.patch (upstreamed)
  - reproducible.patch (upstreamed)
* Mon Mar 25 2019 John Vandenberg <jayvdb@gmail.com>
- Add merged_pr_60.patch to build with recent hypothesis
* Fri Mar 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Regenerate all the cython files
- Run fdupes
* Mon Mar  4 2019 John Vandenberg <jayvdb@gmail.com>
- Remove strange removal of files in %%{buildroot} before the
  %%install
- Use %%license
* Fri May 25 2018 bwiedemann@suse.com
- Add reproducible.patch to make build reproducible (boo#1041090)
* Thu Mar 15 2018 ro@suse.de
- add datrie-bigendian.patch (bsc#1085526)
  to use utf_32_be instead of utf_32_le on bigendian machines
* Tue Apr 11 2017 jengelh@inai.de
- Remove extreme wording from description.
* Fri Apr  7 2017 jmatejek@suse.com
- update license to LGPL-2.1+
* Sat Mar  4 2017 rjschwei@suse.com
- Convert to single-spec
* Sun Jul 17 2016 arun@gmx.de
- initial version 0.7.1
